@@ -9,6 +9,8 @@
 #' for s>2 and s^k-s^k1 - s^(k-k1) + 2, with k1=floor(k/2), for s=2; specifying a
 #' smaller m is beneficial not only for run time but also for possibly achieving a
 #' column-orthogonal array (see Details section)
+#' @param orth logical: if FALSE, suppresses attempts for orthogonal columns and selects the first permissible column for each column of B (see Details section)
+#' @param old logical, relevant for \code{orth=TRUE} only: if TRUE, limits possible columns for B to the columns not eligible for A (instead of the columns not used in A); should only be used for reproducing designs created by version 1.1 or earlier
 #' @param noptim.rounds the number of optimization rounds for each independent restart
 #' @param noptim.repeats the number of independent restarts of optimizations with \code{noptim.rounds} rounds each
 #' @param optimize logical: should optimization be applied? default \code{TRUE}
@@ -31,6 +33,24 @@
 #' (e.g. s=5 with k=3), for which the unoptimized array has a better phi_p than
 #' what can be achieved by most optimization attempts from a random start.
 #'
+#' The search for orthogonal columns can take a long time for larger arrays,
+#' even without optimization. If this is prohibitive (or not considered valuable),
+#' \code{orth=FALSE} causes the function to create the matrix B for equation D=2A+B
+#' with less computational effort.\cr
+#' The subsequent optimization, if not switched off,
+#' is of the same complexity, regardless of the value for \code{orth}. Its
+#' duration heavily depends on the number of optimization steps that are needed
+#' before the algorithm stops. This has not been systematically investigated;
+#' cases for which the total run time with optimization
+#' is shorter for \code{orth=TRUE} than for \code{orth=FALSE} have been observed.
+#'
+#' With package version 1.2, the creation of SOAs has changed: Up to version 1.1,
+#' the columns of B were chosen only from those columns that were \emph{not eligible} for A,
+#' whereas the new version chooses them from those columns that are \emph{not used} for A.
+#' This increases the chance to achieve geometrically orthogonal columns.\cr
+#' Users who want to reproduce a design from an earlier version
+#' can use argument \code{old}.
+#'
 #' @return matrix of class \code{SOA} with the attributes that are listed below. All attributes can be accessed using function \code{\link{attributes}}, or individual attributes can be accessed using function \code{\link{attr}}. These are the attributes:
 #' \describe{
 #'   \item{type}{the type of array (\code{SOA} or \code{OSOA})}
@@ -71,7 +91,7 @@
 #' ## (SOAs are not for situations for which pair coverage
 #' ## is of primary interest)
 #' }
-SOAs2plus_regular <- function(s, k, m=NULL,
+SOAs2plus_regular <- function(s, k, m=NULL, orth=TRUE, old=FALSE,
                           noptim.rounds=1, noptim.repeats=1,
                           optimize=TRUE, dmethod="manhattan", p=50){
   ## the function calls SOAplus2_regular_fast (with optimization)
@@ -124,7 +144,7 @@ SOAs2plus_regular <- function(s, k, m=NULL,
 
     ## A and B according to Hedayat, Cheng and Tang
     ## also takes care of GF
-    AB <- createAB(s, k, m=m)
+    if (!orth) AB <- createAB_fast(s, k, m=m) else AB <- createAB(s, k, m=m, old=old)
     A <- AB$A; B <- AB$B
 
     aus_repeats <- vector(mode="list")
@@ -166,7 +186,7 @@ SOAs2plus_regular <- function(s, k, m=NULL,
                 lapply(combinat::permn(s), function(obj) obj-1), call=mycall)
     aus <- aus$array
   }else{
-  SOA <- SOA2plus_regulart(s, k, m, random=FALSE)
+  SOA <- SOA2plus_regulart(s, k, m, orth=orth, old=old, random=FALSE)
   type <- "SOA"
   if (ocheck(SOA)) type <- "OSOA"
   aus <- SOA
